==> bundesliga_tippspiel-1.8.0-py3-none-any.whl: bundesliga_tippspiel/db/SeasonEvent.py <==
"""LICENSE
Copyright 2017 Hermann Krumrey <hermann@krumreyh.com>

This file is part of bundesliga-tippspiel.

bundesliga-tippspiel is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

bundesliga-tippspiel is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with bundesliga-tippspiel.  If not, see <http://www.gnu.org/licenses/>.
LICENSE"""

from enum import Enum
from puffotter.flask.base import db
from puffotter.flask.db.ModelMixin import ModelMixin


class SeasonEventType(Enum):
    """
    Enumeration that describes all the possible season event types
    """
    PRE_SEASON_MAIL = "pre_season_mail"
    MID_SEASON_REMINDER = "mid_season_reminder"
    POST_SEASON_WRAPUP = "post_season_wrapup"


class SeasonEvent(ModelMixin, db.Model):
    """
    Model that describes the 'season_events' SQL table
    """

    def __init__(self, *args, **kwargs):
        """
        Initializes the Model
        :param args: The constructor arguments
        :param kwargs: The constructor keyword arguments
        """
        super().__init__(*args, **kwargs)

    __tablename__ = "season_events"
    """
    The name of the table
    """

    __table_args__ = (
        db.UniqueConstraint(
            "event_type",
            "season",
            name="unique_season_event"
        ),
    )
    """
    Table arguments for unique constraints
    """

    event_type: SeasonEventType = db.Column(
        db.Enum(SeasonEventType),
        nullable=False
    )
    """
    The type of event
    """

    executed: bool = db.Column(db.Boolean, nullable=False, default=False)
    """
    Whether the event was executed or not
    """

    season: int = db.Column(db.Integer, nullable=False)
    """
    The season this event is for
    """

==> bundesliga_tippspiel-1.10.0-py3-none-any.whl: bundesliga_tippspiel/db/SeasonEvent.py <==
"""LICENSE
Copyright 2017 Hermann Krumrey <hermann@krumreyh.com>

This file is part of bundesliga-tippspiel.

bundesliga-tippspiel is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

bundesliga-tippspiel is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with bundesliga-tippspiel.  If not, see <http://www.gnu.org/licenses/>.
LICENSE"""

from enum import Enum
from jerrycan.base import db
from jerrycan.db.ModelMixin import ModelMixin


class SeasonEventType(Enum):
    """
    Enumeration that describes all the possible season event types
    """
    PRE_SEASON_MAIL = "pre_season_mail"
    MID_SEASON_REMINDER = "mid_season_reminder"
    POST_SEASON_WRAPUP = "post_season_wrapup"


class SeasonEvent(ModelMixin, db.Model):
    """
    Model that describes the 'season_events' SQL table
    """

    def __init__(self, *args, **kwargs):
        """
        Initializes the Model
        :param args: The constructor arguments
        :param kwargs: The constructor keyword arguments
        """
        super().__init__(*args, **kwargs)

    __tablename__ = "season_events"
    """
    The name of the table
    """

    __table_args__ = (
        db.UniqueConstraint(
            "event_type",
            "season",
            name="unique_season_event"
        ),
    )
    """
    Table arguments for unique constraints
    """

    event_type: SeasonEventType = db.Column(
        db.Enum(SeasonEventType),
        nullable=False
    )
    """
    The type of event
    """

    executed: bool = db.Column(db.Boolean, nullable=False, default=False)
    """
    Whether the event was executed or not
    """

    season: int = db.Column(db.Integer, nullable=False)
    """
    The season this event is for
    """
